{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A help button is an interactive element that, when clicked, opens a help modal. This modal provides users with additional information, guidance, or support related to the current page or application feature.</p>

    <p>The help modal can contain text, images, links to documentation, or even videos to assist users.</p>

    <ul>
        <li>Opens a help modal when clicked.</li>
        <li>Provides additional information, guidance, or support.</li>
        <li>Can include text, images, links, and videos.</li>
    </ul>
{% endblock %}
