{% include 'core/help/help_button.html' with help_id='help_modal' %}
{% include 'core/help/help_modal.html' with help_id='help_modal' help_title='How to Cook A Steak' help_content='The final cooked temperature of a medium done steak must be 60&deg;C / 140&deg;F.' %}
