{% extends 'user_account/authentication/page/base_authentication_page.html' %}

{% load crispy_forms_filters %}

{% block registration_content %}
    <form method="post" class="text-white">
        {% csrf_token %}
        {{ form|crispy }}
        <button type="submit" class="d-block mx-auto bg-app-primary btn my-4 w-100">Login</button>
    </form>
    <div class="text-center">
        <a
            href="{% url 'user_account:authentication:admin:password_reset' %}"
            class="fs--1 text-app-secondary cursor-pointer">Forgot my password</a>
    </div>
{% endblock %}



