{% extends 'landing/component/subsection/subsection.html' %}

{% block subsection_title %}
    {% title "Definition" %}
    <h2 id="{{ title|title }}">{{ title }}</h2>
{% endblock %}

{% block subsection_content %}
{% endblock %}
