{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A container is used to group related elements together, providing consistent styling and layout. It helps in organizing page titles, buttons, filters, and other content in a cohesive manner.</p>
    <p>A common use case for a container is to group the page title, buttons, filters, and cards into a unified section.</p>
{% endblock %}
