{% load static %}

<!doctype html>
<html lang="en">
<head>
    <title>{% if seo_title %}{{ seo_title }}{% else %}Django Skeleton{% endif %}</title>

    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">

    <link rel="stylesheet" href="{% static 'core/css/bootstrap.css' %}?v={{ software.version }}">

    <link rel="stylesheet" href="{% static 'core/css/app.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/bootstrap-override.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/bootstrap-extension.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/base.css' %}?v={{ software.version }}">

    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css">

    {% include 'landing/meta/favicons.html' %}
    {% include 'landing/meta/seo_meta.html' %}

    <script type="application/javascript" src="{% static 'core/js/csrf.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/ajax.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/axios.min.js' %}?v={{ software.version }}"></script>

    <script type="application/javascript" src="{% static 'core/js/stratus_alpine.js' %}?v={{ software.version }}"></script>
    <script defer src="{% static 'core/js/alpine-plugins.min.js' %}?v={{ software.version }}"></script>
    <script defer src="{% static 'core/js/alpine.min.js' %}?v={{ software.version }}"></script>

</head>
    <body class="bg-app-layer-one">

        {% block js_script %}
        {% endblock %}

        {% block base_content %}
        {% endblock %}

        <script type="application/javascript" src="{% static 'core/js/bootstrap.bundle.min.js' %}?v={{ software.version }}"></script>

        {% block js_include_bottom %}
        {% endblock %}

    </body>
</html>
