{% extends 'core/accordion/accordion.html' %}

{% block accordion_child_toggle %}
    <i
        @click="toggle()"
        class='cursor-pointer'
        :class="show_accordion ? 'bi bi-dash' : 'bi bi-plus'"
    ></i>
    <span>Step 1.</span>
{% endblock %}

{% block accordion_content %}
	<span class="ps-4">Season steak.</span>
{% endblock %}