{% extends 'core/modal/content/modal_title_content.html' %}

{% block modal_content_title %}
    <h3>Chocolate Chip Cookies</h3>
{% endblock %}

{% block modal_content_content %}
    <h3>Ingredients:</h3>
    <ul>
        <li>1 cup unsalted butter, softened</li>
        <li>1 cup white sugar</li>
        <li>1 cup packed brown sugar</li>
        <li>2 eggs</li>
        <li>2 teaspoons vanilla extract</li>
        <li>1 teaspoon baking soda</li>
        <li>2 teaspoons hot water</li>
        <li>1/2 teaspoon salt</li>
        <li>3 cups all-purpose flour</li>
        <li>2 cups semisweet chocolate chips</li>
        <li>1 cup chopped walnuts (optional)</li>
    </ul>

    <h3>Directions:</h3>
    <ol>
        <li>Preheat oven to 350 degrees F (175 degrees C).</li>
        <li>Cream together the butter, white sugar, and brown sugar until smooth.</li>
        <li>Beat in the eggs one at a time, then stir in the vanilla.</li>
        <li>Dissolve baking soda in hot water. Add to batter along with salt.</li>
        <li>Stir in flour, chocolate chips, and nuts. Drop by large spoonfuls onto ungreased pans.</li>
        <li>Bake for about 10 minutes in the preheated oven, or until edges are nicely browned.</li>
    </ol>
{% endblock %}
