{% include 'core/badge/success_badge.html' with badge_text='Well-done' %}
{% include 'core/badge/primary_badge.html' with badge_text='Medium-well' %}
{% include 'core/badge/secondary_badge.html' with badge_text='Medium' %}
{% include 'core/badge/warning_badge.html' with badge_text='Medium-rare' %}
{% include 'core/badge/danger_badge.html' with badge_text='Rare' %}
