{% extends 'landing/page/full_page.html' %}

{% load static %}

{% block page_content %}
    Broken
{#    {% include 'landing/section/home/block/animation_block.html' with heading='500' subheading='Sorry, there seems to be an error.' button='home' %}#}

{% endblock %}
