{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A tab component is used to organize content into multiple sections that can be easily navigated by switching between tabs. Tabs help in managing and displaying related content without overwhelming the user.</p>

    <p>Each tab typically has a title, and clicking on a tab displays the corresponding content section while hiding others.</p>

    <ul>
        <li>Organizes content into multiple sections.</li>
        <li>Allows users to switch between sections by clicking tabs.</li>
        <li>Improves content management and user experience.</li>
    </ul>
{% endblock %}
