contact_us_context_data = {
    'seo_title': 'Contact Us | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Contact Us | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/contact-us/'
}


boneyard_context_data = {
    'seo_title': 'Boneyard | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Boneyard | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo/primary/django_skeleton_primary_small.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/boneyard/'
}


crypt_context_data = {
    'seo_title': 'Crypt | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Crypt | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo/primary/django_skeleton_primary_small.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/crypt/'
}


asylum_context_data = {
    'seo_title': 'Asylum | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Asylum | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo/primary/django_skeleton_primary_small.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/asylum/'
}


wasteland_context_data = {
    'seo_title': 'Wasteland | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Wasteland | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo/primary/django_skeleton_primary_small.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/wasteland/'
}

component_context_data = {
    'seo_title': 'Component Library | Django Skeleton',
    'seo_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_title': 'Component Library | Django Skeleton',
    'og_description': 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient.',
    'og_image': '/static/website/img/logo/primary/django_skeleton_primary_small.png',
    'og_img_alt': 'Django Skeleton',
    'og_url': 'https://djangoskeleton.com/component/'
}
