{% extends 'landing/component/base/page.html' %}

{% block section_title %}
    Modal
{% endblock %}

{% block section_content %}
    {% include 'landing/component/modal/definition.html' %}
    {% include 'landing/component/modal/example.html' %}
    {% include 'landing/component/modal/gallery.html' %}
{% endblock %}
