{% extends 'core/item/item.html' %}

{% block item_title_col %} d-none{% endblock %}

{% block item_row_content %}
    <div class="col-12 my-0 py-0 d-none">
        {% include 'django_glue/form/glue_field/char_field.html' with glue_field='ingredient.fields.id' x_model_value='ingredient.id' hidden=True prevent_submit=True %}
    </div>
    <div class="col-8">
        {% include 'django_glue/form/glue_field/char_field.html' with glue_field='ingredient.fields.name' x_model_value='ingredient.name' %}
    </div>
    <div class="col-4">
        {% include 'django_glue/form/glue_field/char_field.html' with glue_field='ingredient.fields.quantity' x_model_value='ingredient.quantity' %}
    </div>
    <div class="col-12">
        {% include 'django_glue/form/glue_field/text_field.html' with glue_field='ingredient.fields.directions' x_model_value='ingredient.directions' %}
    </div>
{% endblock %}

{% block item_button %}
	 <span @click="remove_ingredient(index)" class="bi bi-trash text-app-danger cursor-pointer"></span>
{% endblock %}