{% extends 'core/item/item.html' %}

{% block item_title_col %} d-none{% endblock %}

{% block item_row_content %}
	<div class="col">
        {% include 'django_glue/form/field/number_field.html' with glue_field='fact.fields.type' x_model_value='fact.type' %}
    </div>
    <div class="col">
        {% include 'django_glue/form/field/number_field.html' with glue_field='fact.fields.quantity' x_model_value='fact.quantity' %}
    </div>
{% endblock %}