{% extends 'core/item/item.html' %}

{% block item_title_col %} d-none {% endblock %}

{% block item_row_content %}
    <div class="col-lg-3 col-12">
        {% include 'core/element/attribute_element.html' with attribute_title='Recipe Name' attribute_value='Chocolate Cake' %}
    </div>

    <div class="col-lg-3 col-12">
        {% include 'core/element/attribute_element.html' with attribute_title='Preparation Time' attribute_value='45 minutes' %}
    </div>

    <div class="col-lg-3 col-12">
        {% include 'core/element/attribute_element.html' with attribute_title='Cooking Time' attribute_value='30 minutes' %}
    </div>

    <div class="col-lg-3 col-12">
        {% include 'core/element/attribute_element.html' with attribute_title='Servings' attribute_value='8' %}
    </div>
{% endblock %}

{% block item_button %}
    {% include 'core/dropdown/ellipsis_dropdown.html' with view_url='#' edit_url='#' delete_url='#' %}
{% endblock %}
