<li class="nav-item dropdown mx-2">
    <a class="navigation-link text-app-primary text-light-primary-hover py-1 px-2" href="#" id="navbarDropdown"
       role="button" aria-expanded="false">
        {% block dropdown_title %}{% endblock %}
        <i class="bi bi-caret-down-fill ms-1"></i>
    </a>
    <div class="dropdown-menu landing-nav-dropdown py-0" aria-labelledby="navbarDropdown">
        {% block dropdown_content %}
        {% endblock %}
    </div>
</li>