from django.apps import AppConfig


class NutritionConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'app.cookbook.recipe.nutrition'
    label = 'cookbook_recipe_nutrition'
