{% extends 'core/page/full_page.html' %}

{% block page_content %}
    <div class="row">
        <div class="col">
            {% include 'user_account/card/user_list_card.html' with queryset=user_list %}
        </div>
    </div>
{% endblock %}