{% extends 'core/card/title_card.html' %}

{% block card_title %}
	Cookbook
{% endblock %}

{% block card_button %}
	{% if perms.cookbook.change_cookbook %}
        {% url 'cookbook:page:form' pk=cookbook.pk as cookbook_edit_url %}
        {% include 'core/button/primary_dark_button.html' with button_text='Edit' button_icon='bi bi-pencil' button_href=cookbook_edit_url %}
    {% endif %}
{% endblock %}

{% block card_title_content %}
	<div class="row g-3">
        <div class="col-12">
            {% include 'core/element/attribute_element.html' with attribute_title='Name' attribute_value=cookbook.name %}
        </div>
        <div class="col-12">
            {% include 'core/element/attribute_element.html' with attribute_title='Description' attribute_value=cookbook.description|linebreaksbr %}
        </div>
    </div>
{% endblock %}