{% include 'core/base/base.html' %}

{% load static %}

{% block base_content %}
    <div class="container-fluid">
        <div class="row mb-3">
            <div class="col-12">
                {% include 'landing/navigation/top_navigation.html' %}
            </div>
        </div>

        <div class="row mt-3">
            {% include 'landing/component/base/sidebar.html' %}

            <main class="col-md-8">
                <div class="row justify-content-center mb-3">
                    <div class="col-12">
                        {% block page_content %}
                        {% endblock %}
                    </div>
                </div>
            </main>

            {% include 'landing/component/base/overview.html' %}
        </div>

        <div class="row justify-content-center border-top">
            <div class="col-10">
                {% include 'landing/footer/footer.html' %}
            </div>
        </div>
    </div>
{% endblock %}
