{% load static %}

<div class="row justify-content-center align-items-center pt-5 pb-3">
    <div class="col-lg-4 col-12 order-2 order-lg-1 text-center">
        <div class="mb-2">
            <a href="tel:1-(666)-666-6666" class="text-decoration-none text-app-primary">
                <i class="bi bi-telephone-fill me-1"></i>1-(666)-666-6666
            </a>
        </div>
        <div class="mb-2">
            <a href="mailto:cryptkeeper@boneyard.com" class="text-decoration-none text-app-primary">
                <i class="bi bi-envelope-fill me-1"></i>cryptkeeper@boneyard.com
            </a>
        </div>
        <div class="mb-2">
            <i class="bi bi-geo-fill me-1"></i> #666 Cemetery Rd N <br> <span
                class="ms-4">Haunted City, Haunted Province</span>
        </div>
    </div>

    <div class="col-lg-4 col-12 text-center order-1 order-lg-2 pb-4">
        <img src="{% static 'core/img/logo/secondary/django_skeleton_secondary_large.png' %}" alt="Skullybot"
             height="100">
    </div>

    <div class="col-lg-4 d-none d-lg-block order-3">
        <div class="row">
            <div class="col-md-6 pb-3 d-none d-md-block text-center p-0">
                {% url 'landing:boneyard' as boneyard_url %}
                {% include 'landing/footer/element/footer_link_element.html' with url=boneyard_url text='Boneyard' %}
            </div>
            <div class="col-md-6 pb-3 d-none d-md-block text-center p-0">
                {% url 'landing:crypt' as crypt_url %}
                {% include 'landing/footer/element/footer_link_element.html' with url=crypt_url text='Crypt' %}
            </div>
            <div class="col-md-6 pb-3 d-none d-md-block text-center p-0">
                {% url 'landing:asylum' as asylum_url %}
                {% include 'landing/footer/element/footer_link_element.html' with url=asylum_url text='Asylum' %}
            </div>
            <div class="col-md-6 pb-3 d-none d-md-block text-center p-0">
                {% url 'landing:wasteland' as wasteland_url %}
                {% include 'landing/footer/element/footer_link_element.html' with url=wasteland text='Wasteland' %}
            </div>
        </div>
    </div>
</div>

<div class="row pb-3 justify-content-center">
    <div class="col text-center">
        <a class="text-decoration-none text-app-primary fs-4 mx-2"
           href="https://www.linkedin.com/"
           role="button">
            <i class="bi-linkedin"></i>
        </a>
        <a class="text-decoration-none text-app-primary fs-4 mx-2"
           href="https://www.youtube.com/"
           role="button">
            <i class="bi-youtube"></i>
        </a>
        <a class="text-decoration-none text-app-primary text-app-primary-hover fs-4 mx-2"
           href="https://www.twitter.com/"
           role="button">
            <i class="bi-twitter"></i>
        </a>
        <a class="text-decoration-none text-app-primary fs-4 mx-2"
           href="https://www.facebook.com/"
           role="button">
            <i class="bi-facebook"></i>
        </a>
        <a class="text-decoration-none text-app-primary fs-4 mx-2"
           href="https://www.instagram.com/"
           role="button">
            <i class="bi-instagram"></i>
        </a>
        <a class="text-decoration-none text-app-primary fs-4 mx-2" target="_blank" href="https://github.com/"
           role="button">
            <i class="bi-github"></i>
        </a>
    </div>
</div>

<div class="row">
    <div class="col-12 pt-3 pb-2">
        <div class="text-app-primary small text-center">
            All Rights Reserved to Stratus ADV, 2024 ©
        </div>
    </div>
</div>
