{% extends 'core/base/base.html' %}

{% block base_content %}
    <div class="container-fluid">
        {% include 'core/notification/notification.html' %}
        {% include 'core/element/page_loading_element.html' %}

        {% block base_page_content %}
        {% endblock %}
    </div>
{% endblock %}

