{% extends 'core/card/title_card.html' %}

{% block card_title %}
	Link Recipes
{% endblock %}

{% block card_title_content %}
	{% include 'cookbook/form/cookbook_link_recipe_form.html' %}
{% endblock %}