{% extends 'landing/component/base/page.html' %}

{% block section_title %}
    Button
{% endblock %}

{% block section_content %}
    {% include 'landing/component/button/definition.html' %}
    {% include 'landing/component/button/example.html' %}
    {% include 'landing/component/button/gallery.html' %}
{% endblock %}
