{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A page component contains templates for different pages within an application. Pages are used to organize and display various types of content.</p>

    <p>Common examples include:</p>
    <ul>
        <li>app_name_detail_page.html</li>
        <li>app_name_form_page.html</li>
        <li>app_name_list_page.html</li>
    </ul>
{% endblock %}
