{#{% load static %}#}
{##}
{#<meta name="description" content="{{ seo_description }}">#}
{##}
{#<meta property="og:site_name" content="Site Name - Service"/>#}
{#<meta property="og:title" content="{{ og_title }}"/>#}
{#<meta property="og:description" content="{{ og_description }}"/>#}
{#<meta property="og:url" content="{{ og_url }}"/>#}
{#<meta property="og:type" content="website"/>#}
{#<meta property="og:image" content="{{ og_image }}"/>#}
{##}
{#<meta name="twitter:title" content="{{ seo_title }}"/>#}
{#<meta property="twitter:description" content="{{ seo_description }}"/>#}
{#<meta name="twitter:site" content="@Handle"/>#}
{#<meta name="twitter:card" content="summary_large_image"/>#}
{#<meta name="twitter:image" content="{% static '' %}"/>#}
{#<meta property="twitter:image:alt" content="{{ seo_img_alt }}"/>#}
