{% extends 'core/base/base.html' %}

{% load static %}

{% block base_content %}
    <div class="container-fluid">

        {% include 'core/notification/notification.html' %}

        {#     Navigation     #}
        <div class="row mb-3">
            <div class="col-12">
                {% include 'landing/navigation/top_navigation.html' %}
            </div>
        </div>

        {#     Page Content    #}
        <div class="row justify-content-center mb-3">
            <div class="col-xxl-9 col-11">
                {% block page_content %}
                {% endblock %}
            </div>
        </div>

        {#     Footer     #}
        <div class="row justify-content-center border-top">
            <div class="col-10">
                {% include 'landing/footer/footer.html' %}
            </div>
        </div>
    </div>
{% endblock %}