{% extends 'core/accordion/accordion.html' %}

{% block accordion_toggle %}
    {% include 'landing/component/accordion/item/example_recipe_item.html' %}
{% endblock %}

{% block accordion_content %}
    {% include 'landing/component/accordion/example_recipe_step_accordion.html' %}
{% endblock %}
