<div
    x-data="{
        async init() {
            
        },
        nutrition_fact_queryset: new GlueQuerySet('nutrution_fact_queryset'),
        facts: []
    }"
>
    <template x-for="(fact, index) in facts" :key="index">
        {% include 'cookbook/recipe/nutrition/item/nutrition_fact_form_item.html' %}
    </template>
</div>