{% extends 'core/container/container.html' %}

{% block container_title %}
	Recipes
{% endblock %}

{% block container_button %}
	{% include 'core/button/primary_button.html' with button_text='Add' button_icon='bi bi-plus' %}
{% endblock %}

{% block container_filter_section %}
	<form
        x-data="{
            search_recipe() {
                alert('Nothing happens, but imagine in your mind the recipes being filtered!')
            }
        }"
    >
        <label>
            <input class="form-control" type="text" placeholder="Search Ingredients...">
        </label>
        {% include 'core/button/primary_button.html' with button_text='Search' x_button_click="search_recipe()" %}
    </form>
{% endblock %}

{% block container_class %}pt-3{% endblock %}

{% block container_content %}
    {% include 'landing/component/item/example_item.html' %}
{% endblock %}