<div class="fs-6 mb-2">We unfortunately can't glue a model in the view here. Here's what the code would look like if we could!</div>
<div class="fs-5">Create Recipe Form</div>
<form
    class="row"
    x-data="{
        recipe: new GlueModelObject('recipe'),
        async init() {
            await this.recipe.get()
        }
    }"
>
    {% csrf_token %}
    <div class="col-6 py-1">
        {% include 'django_glue/form/glue_field/char_field.html' with glue_field='name' %}
    </div>
    <div class="col-6 py-1">
        {% include 'django_glue/form/glue_field/select_field.html' with glue_field='course' %}
    </div>
    <div class="col-12 py-1">
        {% include 'django_glue/form/glue_field/text_field.html' with glue_field='description' %}
    </div>
    <div class="col-6 py-1">
        {% include 'django_glue/form/glue_field/number_field.html' with glue_field='prep_time' %}
    </div>
    <div class="col-6 py-1">
        {% include 'django_glue/form/glue_field/number_field.html' with glue_field='servings' %}
    </div>
    {% include 'core/form/button/form_submit_button.html' %}
</form>