{% load static %}

<a class="row align-items-center text-white text-app-accent-hover rounded-3 cursor-pointer p-2 mb-1" href="{{ link_href }}">
    <div class="col-2">
        <i class="fs-5 ms-1 me-2 {{ link_icon }}"></i>
    </div>
    <div class="col-8">
             <span class="h6">
                {{ link_title }}
            </span>
    </div>
</a>
