{% extends 'landing/component/base/component.html' %}

{% block page_content %}
    <h1>Homepage</h1>
    <p class="fs-5">
        Welcome to the components page for the Django Skeleton. Here we define, show examples of and display all the different components that we've created.<br><br>

        <i class="fs-4 bi bi-arrow-left"></i> The component pages can be seen by using the left side navigation.<br><br>

        Every component page has a definition, example and gallery section.
        Use the right side navigation to quickly traverse through these different sections. <i class="fs-4 bi bi-arrow-right"></i>
    </p>
{% endblock %}
