{% extends 'landing/component/base/section.html' %}

{% block section_title %}
{% endblock %}

{% block section_content %}
    {% block definition_content %}
    {% endblock %}

    {% block gallery_content %}
    {% endblock %}

    {% block code_content %}
    {% endblock %}
{% endblock %}
