{% extends 'core/page/full_page.html' %}

{% block page_content %}
	<div class="row g-3">
        <div class="col-12">
            {% include 'cookbook/card/cookbook_detail_card.html' %}
        </div>
        <div class="col-8">
            {% include 'cookbook/recipe/card/recipe_list_card.html' %}
        </div>
        <div class="col-4">
            {% include 'history/card/activity_list_card.html' with activity_log=cookbook.activity_log.prefetch_user %}
        </div>
    </div>
{% endblock %}