{% extends 'core/card/title_card.html' %}

{% block card_title %}
    Ingredients
{% endblock %}

{% block card_button %} {% endblock %}

{% block card_title_content %}
    {% if ingredients %}
        {% for ingredient in ingredients %}
            {% include 'cookbook/recipe/item/ingredient_item.html' %}
        {% endfor %}
    {% else %}
        {% include 'core/item/no_data_item.html' %}
    {% endif %}
{% endblock %}