{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A form component contains all the templates for creating and managing forms. Forms are used to collect user input and submit data.</p>

    <p>Forms can include various fields, which can be organized into a directory to improve readability.</p>

    <ul>
        <li>Contains all form templates.</li>
        <li>Fields:</li>
        <ul>
            <li>Optional directory for better organization and readability.</li>
            <li>Includes all the necessary fields for the form.</li>
        </ul>
    </ul>
{% endblock %}
