{% extends 'core/page/full_page.html' %}

{% block page_content %}
	<div class="row">
        <div class="col-12">
            {% include 'cookbook/card/cookbook_list_card.html' %}
        </div>
    </div>
{% endblock %}