{% extends 'core/page/base_page.html' %}

{% load static %}

{% block base_page_content %}
    <div class="row justify-content-center mt-6 text-white">
        <div class="col-4 bg-app-side-bar rounded-3">
            <div class="p-4">
                <div class="text-center">
                    <a href="/django_spire/static">
                        <img height="95px" class="ms-1" src="{% static 'core/img/logo/icon/django_skeleton_icon_body_small.png' %}" alt="">
                        <div>Django Skeleton</div>
                    </a>
                </div>
                {% block registration_content %}

                {% endblock %}
            </div>
        </div>
    </div>
{% endblock %}

