{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A button is an interactive element that triggers an action or event when clicked. Buttons are used throughout an interface to submit forms, initiate processes, or navigate between pages.</p>

    <p>Buttons can vary in size, color, and style to indicate their importance or the type of action they perform. They often include text or icons to clarify their function.</p>

    <ul>
        <li>Triggers actions or events on click.</li>
        <li>Used for form submissions, navigation, and process initiation.</li>
        <li>Customizable in size, color, and style for different contexts.</li>
    </ul>
{% endblock %}
