{% extends 'core/card/title_card.html' %}

{% block card_title %}
	Recipe
{% endblock %}

{% block card_button %}
	{% if perms.cookbook_recipe.change_recipe %}
        {% url 'cookbook:recipe:page:form' pk=recipe.pk as recipe_edit_url %}
		{% include 'core/button/primary_dark_button.html' with button_text='Edit' button_icon='bi bi-pencil' button_href=recipe_edit_url %}
	{% endif %}
{% endblock %}

{% block card_title_content %}
	<div class="row">
        <div class="col">
            {% include 'core/element/attribute_element.html' with attribute_title='Name' attribute_value=recipe.name %}
        </div>
        <div class="col">
            {% include 'core/element/attribute_element.html' with attribute_title='Course' %}
            {% include 'core/badge/primary_badge.html' with badge_text=recipe.choice_verbose %}
        </div>
    </div>
{% endblock %}