<div class="">
    <div class="container-fluid text-light text-end">
        <div class="row justify-content-end">
            <div class="col-auto d-flex ">
                {% include 'landing/navigation/elements/nav_link.html' with url='#' text='Login' %}
                </div>
        </div>
    </div>
</div>