<div class="card ms-0 rounded-3 {% block card_outer_class %}{% endblock %}">
    <div class="{% block card_padding %}p-3{% endblock %}" style="{% block card_body_style %}{% endblock %}">
        {% block card_content %}{% endblock %}
    </div>
    {% block card_footer %}{% endblock %}
</div>