{% extends 'core/page/base_page.html' %}

{% block base_page_content %}
    <div class="row">
        <div class="col-auto px-0 d-none d-lg-block" style="width: 180px">
            {% block navigation_side %}
                {% include 'core/navigation/side_navigation.html' %}
            {% endblock %}
        </div>

        <div class="col">
            <div class="row">
                <div class="col-12 sticky-top">
                    {% block navigation_top %}
                        {% include 'core/navigation/top_navigation.html' with hide_logo=True %}
                    {% endblock %}
                </div>

                <div class="col-12">
                    {% block page_content %}
                    {% endblock %}
                </div>

                <div class="col-12 mt-2">
                    {% block navigation_bottom %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
