<div class="row">
    <div class="col">
        Click the ellipsis on the right to see the magic!
    </div>
    <div class="col-auto">
        <div class="mx-2">
            {% include 'core/dropdown/ellipsis_dropdown.html' with view_url='#' edit_url='#' delete_url='#' %}
        </div>
    </div>
</div>
