{% load static %}
{% load django_glue %}

<!doctype html>
<html lang="en">
<head>
    <title>Django Skeleton {% if page_title %}- {{ page_title }}{% endif %}</title>

    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Karla:ital,wght@0,200..800;1,200..800&family=Merriweather:ital,wght@0,300;0,400;0,700;0,900;1,300;1,400;1,700;1,900&display=swap" rel="stylesheet">
    {% include 'landing/meta/favicons.html' %}

    <link rel="stylesheet" href="{% static 'core/css/bootstrap.css' %}?v={{ software.version }}">

    <link rel="stylesheet" href="{% static 'core/css/app.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/bootstrap-override.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/bootstrap-extension.css' %}?v={{ software.version }}">
    <link rel="stylesheet" href="{% static 'core/css/base.css' %}?v={{ software.version }}">

    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">
    <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>

    <script src="https://cdn.jsdelivr.net/npm/echarts@5.4.3/dist/echarts.min.js"></script>

    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.1/font/bootstrap-icons.css"
          integrity="sha384-4LISF5TTJX/fLmGSxO53rV4miRxdg84mZsxmO8Rx5jGtp/LbrixFETvWa5a6sESd" crossorigin="anonymous">

    <script type="application/javascript" src="{% static 'core/js/base.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/csrf.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/ajax.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/axios.min.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/stratus_alpine.js' %}?v={{ software.version }}"></script>
    <script type="application/javascript" src="{% static 'core/js/dispatch_modal.js' %}?v={{ software.version }}"></script>

    <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/intersect@3.x.x/dist/cdn.min.js"></script>
    <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/mask@3.x.x/dist/cdn.min.js"></script>
    <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/collapse@3.x.x/dist/cdn.min.js"></script>
    <script defer src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js"></script>
</head>
<body class="bg-app-layer-one vh-100">
    {% block js_script %}
    {% endblock %}

    {% block base_content %}
    {% endblock %}

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz"
        crossorigin="anonymous"></script>

    {% block js_include_bottom %}
    {% endblock %}

    {% include 'core/modal/dispatch_modal.html' %}

    {% glue_init %}
</body>
</html>
