{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>An element represents an individual component in templates. Unlike items, elements do not repeat on the same page as a list. They are used for standalone components that appear consistently across multiple templates.</p>
    <p>If a component repeats across multiple templates, an element file can be created for it.</p>
    <p>An example of an element component is a search bar for a specific page.</p>
{% endblock %}
