<div
    class="py-1"
    x-data="{
        submit_recipe() {
            alert('Recipe has been submitted!')
        }
    }"
>
    {% include 'core/button/primary_button.html' with button_text='Submit Recipe' x_button_click="submit_recipe()" %}
</div>
