{% extends 'landing/component/subsection/definition.html' %}

{% block subsection_content %}
    <p>A notification component is used to alert users with various statuses or messages. Notifications can provide feedback about user actions, inform about updates, or display error messages.</p>

    <p>Notifications can appear as banners, toasts, or modal dialogs and are often color-coded to indicate the type of message, such as success, error, warning, or information.</p>

    <ul>
        <li>Alerts users with statuses or messages.</li>
        <li>Provides feedback, updates, or error messages.</li>
        <li>Can appear as banners, toasts, or modal dialogs.</li>
        <li>Color-coded to indicate message type (success, error, warning, information).</li>
    </ul>
{% endblock %}
