{% load static %}

<link rel="apple-touch-icon" sizes="180x180" href="{% static 'core/favicons/apple-touch-icon.png' %}">
<link rel="icon" type="image/png" sizes="32x32" href="{% static 'core/favicons/favicon-32x32.png' %}">
<link rel="icon" type="image/png" sizes="16x16" href="{% static 'core/favicons/favicon-16x16.png' %}">
<link rel="manifest" href="{% static 'core/favicons/site.webmanifest' %}">
<link rel="mask-icon" color="#5bbad5" href="{% static 'core/favicons/safari-pinned-tab.svg' %}">
<meta name="msapplication-TileColor" content="#2b5797">
<meta name="theme-color" content="#ffffff">