{% extends 'landing/page/full_page.html' %}

{% block page_content %}
    <div class="my-md-10 my-5 py-5 text-center">
        <h3 class="fs-md-3 fs-1 mb-3">
            Thanks for contacting our company!
        </h3>
        <div class="fs-md-2 fs-0 mb-3">
            We will get back to you as soon as possible.
        </div>
        <a href="{% url 'landing:home' %}" class="btn bg-app-primary text-white">Return Home</a>
    </div>
{% endblock %}