{% extends 'core/card/title_card.html' %}

{% block card_title %}
    🍔 Food Card 🍕
{% endblock %}

{% block card_title_content %}
    🍦 This card contains delicious food emojis! 🍩
{% endblock %}

{% block card_button %}
    <div @click="toggle_card_title_dropdown()">
        {% include 'core/button/primary_button.html' with button_text='Toggle Food Dropdown' %}
    </div>
{% endblock %}

{% block card_dropdown_content %}
    <p>Chicken 🍗 and Beer 🍻</p>
{% endblock %}
